@@ -144,12 +144,20 @@ impl CorrelatorContext {
             ));
         }
         // Do gpubox stuff only if we have gpubox files.
-        let gpubox_info = examine_gpubox_files(&gpubox_filenames, metafits_context.obs_id)?;
+        let gpubox_info = examine_gpubox_files(gpubox_filenames, metafits_context.obs_id)?;
 
         // Populate metafits coarse channels and timesteps now that we know what MWA Version we are dealing with
         // Populate the coarse channels
         metafits_context.populate_expected_coarse_channels(gpubox_info.mwa_version)?;
 
+        // Now populate the fine channels
+        metafits_context.metafits_fine_chan_freqs = CoarseChannel::get_fine_chan_centres_array_hz(
+            gpubox_info.mwa_version,
+            &metafits_context.metafits_coarse_chans,
+            metafits_context.corr_fine_chan_width_hz,
+            metafits_context.num_corr_fine_chans_per_coarse,
+        );
+
         // Populate the timesteps
         metafits_context.populate_expected_timesteps(gpubox_info.mwa_version)?;
 
@@ -355,6 +363,33 @@ impl CorrelatorContext {
         })
     }
 
+    /// For a given slice of correlator coarse channel indices, return a vector of the center
+    /// frequencies for all the fine channels in the given coarse channels
+    ///
+    /// # Arguments
+    ///
+    /// * `corr_coarse_chan_indices` - a slice containing correlator coarse channel indices
+    ///                                for which you want fine channels for. Does not need to be
+    ///                                contiguous.
+    ///
+    ///
+    /// # Returns
+    ///
+    /// * a vector of f64 containing the centre sky frequencies of all the fine channels for the
+    ///   given coarse channels.
+    ///
+    pub fn get_fine_chan_freqs_hz_array(&self, corr_coarse_chan_indices: &[usize]) -> Vec<f64> {
+        CoarseChannel::get_fine_chan_centres_array_hz(
+            self.mwa_version,
+            &corr_coarse_chan_indices
+                .iter()
+                .map(|c| self.coarse_chans[*c].clone())
+                .collect::<Vec<CoarseChannel>>(),
+            self.metafits_context.corr_fine_chan_width_hz,
+            self.metafits_context.num_corr_fine_chans_per_coarse,
+        )
+    }
+
     /// Read a single timestep for a single coarse channel
     /// The output visibilities are in order:
     /// baseline,frequency,pol,r,i
